/* _______________________________________________________________________
	TrinityAudio.h - Audio pipe constants for Trinity
	
	first created: 4/3/2001
	
	copyright  1999-2000 by David DeHaven - all rights reserved.
 _______________________________________________________________________*/

#ifndef _TrinityAudio_
#define _TrinityAudio_

	#include <Trinity/TrinityCommon.h>

#ifdef __cplusplus
extern "C" {
#endif

enum {
	kTRPipeTypeAudio = 'Adio',
	
	/* Setting Selectors				   GET/SET IN/OUT - allowed access modes */
		/* audio pipe settings */
	kTRAudioSource = 'Asrc',			/* GET/SET IN/OUT - which audio source to use (if selectable) */
	
	kTRAudioDescription = 'Adsc',		/* GET     IN/OUT - AudioStreamBasicDescription needed to work with CoreAudio, you must TRFree() this when done */
	
	kTRAudioFormat = 'Afmt',			/* GET     IN/OUT - type of audio being handled (AIFF, wav, mp3, pcm, uLaw, etc...) */
	kTRAudioMode = 'Amod',				/* GET/SET IN/OUT - Audio mode, mono/stereo/DTS/etc... */
	kTRAudioSampleRate = 'Asrt',		/* GET     IN/OUT - sampling bit rate (eg: 22KHz, 44 KHz, etc...) */
	kTRAudioNumberOfChannels = 'A#ch',	/* GET     IN/OUT - number of audio channels per sample */
	kTRAudioSampleSize = 'Assz',		/* GET     IN/OUT - size of each channels sample in bytes */
	kTRAudioBufferSize = 'Absz',		/* GET     IN/OUT - size of each packet sent through the pipe */
	
	kTRAudioBitRate = 'Abrt',			/* GET/SET IN/OUT - bit rate for audio data, in kilobits per second (eg: 384 = 384 KB/s)*/
	kTRAudioCRC = 'Acrc',				/* GET/SET IN     - turn on audio data crc generation */
	
	kTRAudioVolume = 'Avol',			/* GET/SET IN/OUT - 0-65535 */
	kTRAudioBalance = 'Abal',			/* GET/SET IN/OUT - -32768-32767, full left to full right respectively */
	kTRAudioLowEQ = 'Aleq',				/* GET/SET IN/OUT - Bass EQ control (frequency ranges TBD...) */
	kTRAudioMidEQ = 'Ameq',				/* GET/SET IN/OUT - Mid-range EQ control */
	kTRAudioHighEQ = 'Aheq',			/* GET/SET IN/OUT - Treble EQ control */
};

enum {
	/* various audio data formats */
	kTRAudioFormatLinearPCM = 'lpcm',			/* integer PCM */
	kTRAudioFormatLinearPCM_Float = 'fpcm',		/* floating point PCM */
	kTRAudioFormatMPEG1_Layer1 = 'M1L1',
	kTRAudioFormatMPEG1_Layer2 = 'M1L2',
	kTRAudioFormatMPEG1_Layer3 = 'M1L3',
	kTRAudioFormatMPEG2_AC3 = 'AC3 '
};

enum {
	/* likely audio sources */
	kTRAudioSourceType_Tuner = 0,
	kTRAudioSourceType_External,
	kTRAudioSourceType_Passthru,	/* need to expand on this? */
	
	/* audio mode values */
	kTRAudioMode_Mono = 0,		/* 1 channel monaural, or stereo mixed into 1 channel */
	kTRAudioMode_Stereo,		/* 2 channel stereo (could be expanded too...) */
	kTRAudioMode_AC3,			/* Digitally Encoded Audio (AC-3) */
	kTRAudioMode_DTS,			/* Sony DTS encoded Audio */
	kTRAudioMode_Dolby,			/* Analog Dolby surround (handled like stereo) */
	kTRAudioMode_Dolby_Digital,	/* Dolby digital surround */
	kTRAudioMode_THX,
	kTRAudioMode_JointStereo,	/* Joint stereo */
	kTRAudioMode_SAP,			/* SAP support */
	
	/* audio sampling rates, in Hz (can also be bits/second for bit rate) */
	kTRSampleRate_11Khz = 11000,
	kTRSampleRate_16KHz = 16000,
	kTRSampleRate_22Khz = 22000,
	kTRSampleRate_24Khz = 24000,
	kTRSampleRate_32Khz = 32000,
	kTRSampleRate_44_1Khz = 44100,
	kTRSampleRate_48Khz = 48000,
	kTRSampleRate_96Khz = 96000,
	kTRSampleRate_112Khz = 112000,
	kTRSampleRate_128KHz = 128000,
	kTRSampleRate_192KHz = 192000,
	kTRSampleRate_224Khz = 224000,
	kTRSampleRate_384KHz = 384000,
	kTRSampleRate_512KHz = 512000,
	
	/* audio volume levels (unsigned 16 bit range) - linearity is assumed,
	   hardware driver or firmware should adjust for non-linear devices
	   Note: setting balance level may adjust volume levels of individual channels */
	kTRVolume_Off = 0,
	kTRVolume_1Quarter = 16384,
	kTRVolume_Half = 32768,
	kTRVolume_3Quarter = 49152,
	kTRVolume_Full = 65535,			/* should we determine DB range? We could... */
	
	/* audio balance levels (signed 16 bit range) */
	kTRBalance_Full_Left = -32768,
	kTRBalance_Half_Left = -16384,
	kTRBalance_Centered = 0,
	kTRBalance_Half_Right = 16384,
	kTRBalance_Full_Right = 32767,
	
	/* EQ levels */
	kTREQLevel_Minimum = -32768,	/* EQ channels are determined by hardware, application should NOT assume */
	kTREQLevel_Centered = 0,		/* any number of channels to be available */
	kTREQLevel_Maximum = 32767		/* channels will be marked with freq range, so lazy programmers can deal with this */
};

enum {
		/* Audio pipe errors */
	kTRAudioInvalidSampleRateErr = 2000,
	kTRAudioInvalidBitRateErr,
	kTRAudioInvalidFormatErr,
	kTRAudioInvalidModeErr,
};

#ifdef __cplusplus
}
#endif

#endif /* _TrinityAudio_ */

/*______________________________________________________________________*/
