/* _______________________________________________________________________
	TrinityMPEG.h - MPEG I/O pipe constants for Trinity
	
	first created: 8/13/2003
	
	copyright  1999-2001 by David DeHaven - all rights reserved.
 _______________________________________________________________________*/

#ifndef _TrinityMPEG_
#define _TrinityMPEG_

	#include <Trinity/TrinityCommon.h>

#ifdef __cplusplus
extern "C" {
#endif

enum {
	kTRPipeTypeMPEG = 'MPGp',				/* IN or OUT */
	
	/* Setting Selectors					   GET/SET IN/OUT - allowed access modes */
	kTRMPEG_ProfileList = 'Mpls',			/* GET     IN/OUT - returns a list of MPEG setting profiles as XML data */
	kTRMPEG_ProfileListSize = 'Mpsz',		/* GET     IN/OUT - returns the size of the MPEG profile list */
	kTRMPEG_CurrentProfile = 'Mprf',		/* GET/SET IN/OUT - selected MPEG profile ID, if 0, then custom settings are in use */
	
	kTRMPEG_PacketSize = 'Mpkt',			/* GET     IN/OUT - returns/sets the size of MPEG data packets coming from the driver */
	
	kTRMPEG_StreamType = 'Mstr',			/* GET/SET IN     - type of MPEG stream being captured (see types below) */
	
	kTRMPEG_GOPSize = 'Mgop',				/* GET/SET IN     - number of frames in each GOP */
	
		/* data rate settings */
	kTRMPEG_EnableVBR = 'Mvbr',				/* GET/SET IN     - enable variable bitrate, 1 = turn vbr on */
	kTRMPEG_TargetBitRate = 'Mrat',			/* GET/SET IN     - target data bitrate, in kilobits/sec (eg: 1200 = 1.2 megabits/s) */
	kTRMPEG_PeakBitRate = 'Mpkr',			/* GET/SET IN     - maximum bitrate, only applicable to VBR */
	
	kTRMPEG_EnableInverseTelecine = 'Mtlc',	/* GET/SET IN     - enable inverse telecine (3:2 pulldown), 1 = on */
};

/*
	For devices that support video, the following settings selectors from TrinityVideo.h are supported:
		kTRVideoSource
		kTRVideoSourceList
		kTRVideoStandard
		kTRVideoSize
		kTRVideoAspectRatio
		kTRVideoStatus
		kTRVideoHue
		kTRVideoBrightness
		kTRVideoContrast
		kTRVideoSaturation
		kTRVideoSharpness
	
	For devices that support audio, the following selectors from TrinityAudio.h are supported:
		kTRAudioSource
		kTRAudioFormat
		kTRAudioSampleRate
		kTRAudioNumberOfChannels
		kTRAudioBitRate
		kTRAudioVolume
		kTRAudioBalance
		kTRAudioLowEQ
		kTRAudioMidEQ
		kTRAudioHighEQ
	
	Actual support is dependent on each device implementation.
*/

enum {
		/* settings for kTRMPEG_StreamType */
	kTRMPEG_StreamType_MPEG1 = 'mpg1',		/* MPEG-1 elementary stream */
	kTRMPEG_StreamType_VCD = 'VCD ',		/* MPEG-1 VCD stream */
	
	kTRMPEG_StreamType_Program = 'prog',	/* MPEG-2 program stream */
	kTRMPEG_StreamType_Transport = 'tran',	/* MPEG-2 transport stream */
	kTRMPEG_StreamType_DVD = 'DVD ',		/* MPEG-2 DVD stream */
	kTRMPEG_StreamType_SVCD = 'SVCD'		/* MPEG-2 SVCD stream */
};

/* XML data keys for profile information */
#define kTRMPEG_KEY_ProfileID "Profile ID"					/* number - unique profile identifier */

#define kTRMPEG_KEY_StreamType "Stream Type"				/* string - The type of MPEG stream, convert to a four character code */

#define kTRMPEG_KEY_GOPSize "GOP Size"						/* number - How many frames per GOP */

#define kTRMPEG_KEY_EnableVBR "Enable VBR"					/* boolean - turn variable bit rate mode on or off */
#define kTRMPEG_KEY_TargetBitRate "Target Bit Rate"			/* number - target bit rate, in kilobits per second (eg: 1200 for 1.2 megabits/s) */
#define kTRMPEG_KEY_PeakBitRate "Peak Bit Rate"				/* number - maximum bit rate, only applies to variable bit rate */

#define kTRMPEG_KEY_ImageWidth "Image Width"				/* number - image width in pixels */
#define kTRMPEG_KEY_ImageHeight "Image Height"				/* number - image height in pixels */

#define kTRMPEG_KEY_AudioType "Audio Type"					/* string - type of audio present (stereo, joint stereo, dual channel, etc...) */
#define kTRMPEG_KEY_AudioFormat "Audio Format"				/* string - audio data format (MPEG-1 layer 2, etc...) */
#define kTRMPEG_KEY_AudioSampleRate "Audio Sample Rate"		/* number - sampling rate in Hz (eg: 48000 for 48 KHz) */
#define kTRMPEG_KEY_AudioBitRate "Audio Bit Rate"			/* number - audio data bit rate, in KHz (eg: 384 for 384 KHz) */
#define kTRMPEG_KEY_AudioCRCEnable "Audio CRC"				/* boolean - enables audio CRC if set to yes */

#define kTRMPEG_KEY_EnableInverseTelecine "Enable Inverse Telecine" /* boolean - turn inverse telecine on or off */

enum {
		/* MPEG pipe errors */
	kTRMPEG_InvalidProfileErr = 1000,
	kTRMPEG_InvalidStreamTypeErr,
	kTRMPEG_InvalidGOPSizeErr,
	kTRMPEG_InvalidRateErr,				// applies to target and peak data rates
		// audio and video pipe errors returned for those selectors
};

#ifdef __cplusplus
}
#endif

#endif /* _TrinityMPEG_ */

/*______________________________________________________________________*/
